Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrClosed is the error resulting if the pool is closed via pool.Close(). ErrClosed = errors.New("pool is closed") )
Functions ¶
This section is empty.
Types ¶
type IOSessionPool ¶
type IOSessionPool interface {
// Get returns a new connection from the pool. Closing the connections puts
// it back to the Pool. Closing it when the pool is destroyed or full will
// be counted as an error.
Get() (goetty.IOSession, error)
// Put puts the connection back to the pool. If the pool is full or closed,
// conn is simply closed. A nil conn will be rejected.
Put(goetty.IOSession) error
// Close closes the pool and all its connections. After Close() the pool is
// no longer usable.
Close()
// Len returns the current number of connections of the pool.
Len() int
}
IOSessionPool interface describes a pool implementation. A pool should have maximum capacity. An ideal pool is threadsafe and easy to use.
func NewIOSessionPool ¶
func NewIOSessionPool(remote interface{}, initialCap, maxCap int, factory Factory) (IOSessionPool, error)
NewIOSessionPool returns a new pool based on buffered channels with an initial capacity and maximum capacity. Factory is used when initial capacity is greater than zero to fill the pool. A zero initialCap doesn't fill the Pool until a new Get() is called. During a Get(), If there is no new connection available in the pool, a new connection will be created via the Factory() method.
Click to show internal directories.
Click to hide internal directories.